##  Guidelines and Best Practices
  * Identify short- or long-term objectives by talking with organization leaders or reviewing strategy documents, mission and vision statements, business plans, or similar resources.
  * If your organization uses Objectives and Key Results (OKR), it is recommended to include defined objectives.
  * Add a maximum of 2 hierarchy levels.
  * Ensure that your objectives are SMART (specific, measurable, achievable, relevant, and time-bound), e.g., ‘Reduce IT Costs by 20% in 2024’.
  * The objective should include a currency, percentage, or count to ensure it is measurable.
  * As an enterprise architect, work with stakeholders to:
    * identify business capabilities improved by objectives.
    * define initiatives that work together to achieve a common objective.
    * use the [SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning?locale=en-US&state=PRODUCTION&version=CLOUD "The SAP LeanIX Architecture and Road Map Planning enhances SAP LeanIX Application Portfolio Management by offering advanced features for seamless planning and execution of transformation initiatives in enterprise architecture management.") to:
      * model transformations and IT landscape impacts.
      * visualize roadmaps and IT landscape changes over time.
      * track initiative progress, reflect changes as they’re delivered, and report on achievement of objectives.
  * Differentiate objectives from initiatives. Objectives represent the business goals, while initiatives capture transformation activities to reach the goals. In the example “A company wants to move internal applications into the cloud by 2025 to increase IT efficiency by 20%”, the first part, “move internal applications into the cloud by 2025,” is the initiative, and "increase IT efficiency by 20% [by 2025]” is the objective.
